# natspy-lock

[![PyPI - Version](https://img.shields.io/pypi/v/natspy-lock.svg)](https://pypi.org/project/natspy-lock)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/natspy-lock.svg)](https://pypi.org/project/natspy-lock)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install natspy-lock
```

## License

`natspy-lock` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
